TileEntry

Struct TileEntry 

pub struct TileEntry {
    pub w: u8,
    pub h: u8,
    pub cluster_index: u16,
}
Keeps track of a texture tile’s dimensions and location in the tile pixel buffer.

Fields

w: u8

Width of the tile.

h: u8

Height of the tile.

cluster_index: u16

Index to the first cluster of the tile in the tile buffer. Each cluster is 1 byte.